from .base import Upstream
from .git import GitUpstream
from .local import LocalUpstream
from .null import NullUpstream
from .source_package import SourcePackageUpstream
